@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2004-2006 Zuza Software Foundation
@@ -67,7 +66,7 @@ def main(argv=None):
                ("it.po", "it"): ("it", prop2mozfunny.po2it),
                ("ini.po", "ini"): ("ini", prop2mozfunny.po2ini),
                ("inc.po", "inc"): ("inc", prop2mozfunny.po2inc),
-               ("lang.po", "lang"): ("lang", po2mozlang.convertlang),
+               ("lang.po", "lang"): ("lang", po2mozlang.run_converter),
                # (None, "*"): ("*", convert.copytemplate),
                ("*", "*"): ("*", convert.copyinput),
                "*": ("*", convert.copyinput)}
@@ -80,15 +79,13 @@ def main(argv=None):
                                                    replacer.searchreplaceinput)
         formats[replaceformat] = (replaceformat, replacer.searchreplaceinput)
     parser = MozConvertOptionParser(formats, usetemplates=True, description=__doc__)
-    parser.add_option("-l", "--locale", dest="locale", default=None,
+    parser.add_option(
+        "-l", "--locale", dest="locale", default=None,
         help="set output locale (required as this sets the directory names)",
         metavar="LOCALE")
-    parser.add_option("", "--removeuntranslated", dest="remove_untranslated",
-            default=False, action="store_true",
-            help="remove untranslated strings from output")
     parser.add_threshold_option()
     parser.add_fuzzy_option()
-    parser.passthrough.append("remove_untranslated")
+    parser.add_remove_untranslated_option()
     parser.replacer = replacer
     parser.run(argv)
 
