@@ -261,9 +261,9 @@ newlines.</p></body></html>
         self.countunits(pofile, 2)
         # FIXME change this so that we check that the msgctxt is correctly added
         self.compareunit(pofile, 1, "Duplicate")
-        assert pofile.units[1].getlocations() == ['None html.body.p:1-26']
+        assert pofile.units[1].getlocations() == ['None+html.body.p:1-26']
         self.compareunit(pofile, 2, "Duplicate")
-        assert pofile.units[2].getlocations() == ['None html.body.p:1-42']
+        assert pofile.units[2].getlocations() == ['None+html.body.p:1-42']
 
     def test_multiline_reflow(self):
         """check that we reflow multiline content to make it more readable for translators"""
@@ -384,13 +384,13 @@ years has helped to bridge the digital divide to a limited extent.</p> \r
         self.check_phpsnippet('''<?=($a < $b ? $foo : ($b > c ? $bar : $cat))?>''')
 
         # Make sure basically any symbol can be handled
-        self.check_phpsnippet(''' <? asdfghjkl qwertyuiop 1234567890!@#$%^&*()-=_+[]\{}|;':",./<>? ?> ''')
+        self.check_phpsnippet(''' <? asdfghjkl qwertyuiop 1234567890!@#$%^&*()-=_+[]\\{}|;':",./<>? ?> ''')
 
     def test_multiple_php(self):
         """Test multiple PHP snippets in a string to make sure they get restored properly"""
         php1 = '''<?=$phpvariable?>'''
         php2 = '''<?=($a < $b ? $foo : ($b > c ? $bar : $cat))?>'''
-        php3 = '''<? asdfghjklqwertyuiop1234567890!@#$%^&*()-=_+[]\{}|;':",./<>? ?>'''
+        php3 = '''<? asdfghjklqwertyuiop1234567890!@#$%^&*()-=_+[]\\{}|;':",./<>? ?>'''
 
         # Put 3 different strings into an html string
         innertext = '<a href="' + php1 + '/site.html">Body text</a> and some ' + php2 + ' more text ' + php2 + php3
@@ -429,9 +429,9 @@ class TestHTML2POCommand(test_convert.TestConvertCommand, TestHTML2PO):
     convertmodule = html2po
     defaultoptions = {"progress": "none"}
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE")
         options = self.help_check(options, "--keepcomments")
