@@ -46,7 +46,7 @@ msgstr "Toepassings"
         assert tmx.translate("Applications") == "Toepassings"
         assert tmx.translate("bla") is None
         xmltext = bytes(tmx).decode('utf-8')
-        assert xmltext.index('creationtool="Translate Toolkit - po2tmx"')
+        assert xmltext.index('creationtool="Translate Toolkit"')
         assert xmltext.index('adminlang')
         assert xmltext.index('creationtoolversion')
         assert xmltext.index('datatype')
@@ -192,9 +192,9 @@ class TestPO2TMXCommand(test_convert.TestConvertCommand, TestPO2TMX):
     """Tests running actual po2tmx commands on files"""
     convertmodule = po2tmx
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-l LANG, --language=LANG")
         options = self.help_check(options, "--source-language=LANG")
         options = self.help_check(options, "--comments", last=True)
