@@ -157,7 +157,7 @@ languages = {
     'pt': ('Portuguese', 2, '(n != 1)'),
     'pt_BR': ('Portuguese (Brazil)', 2, '(n > 1)'),
     'rm': ('Romansh', 2, '(n != 1)'),
-    'ro': ('Romanian', 3, '(n==1 ? 0 : (n==0 || (n%100 > 0 && n%100 < 20)) ? 1 : 2);'),
+    'ro': ('Romanian', 3, '(n==1 ? 0 : (n==0 || (n%100 > 0 && n%100 < 20)) ? 1 : 2)'),
     'ru': ('Russian', 3,
            '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
     'rw': ('Kinyarwanda', 2, '(n != 1)'),
@@ -165,6 +165,7 @@ languages = {
     'sah': ('Yakut', 1, '0'),
     'sat': ('Santali', 2, '(n != 1)'),
     'sco': ('Scots', 2, '(n != 1)'),
+    'scn': ('Sicilian', 2, '(n != 1)'),
     'sd': ('Sindhi', 2, '(n != 1)'),
     'se': ('Northern Sami', 2, '(n != 1)'),
     'si': ('Sinhala; Sinhalese', 2, '(n != 1)'),
@@ -355,6 +356,7 @@ plural_tags = {
     'bs': ['one', 'few', 'other'],
     'ca': ['one', 'other'],
     'ce': ['one', 'other'],
+    'ceb': ['one', 'other'],
     'cgg': ['one', 'other'],
     'chr': ['one', 'other'],
     'ckb': ['one', 'other'],
@@ -395,6 +397,7 @@ plural_tags = {
     'hsb': ['one', 'two', 'few', 'other'],
     'hu': ['one', 'other'],
     'hy': ['one', 'other'],
+    'ia': ['one', 'other'],
     'id': ['other'],
     'ig': ['other'],
     'ii': ['other'],
@@ -427,7 +430,7 @@ plural_tags = {
     'ksb': ['one', 'other'],
     'ksh': ['zero', 'one', 'other'],
     'ku': ['one', 'other'],
-    'kw': ['one', 'two', 'other'],
+    'kw': ['zero', 'one', 'two', 'few', 'many', 'other'],
     'ky': ['one', 'other'],
     'lag': ['zero', 'one', 'other'],
     'lb': ['one', 'other'],
@@ -480,6 +483,8 @@ plural_tags = {
     'rwk': ['one', 'other'],
     'sah': ['other'],
     'saq': ['one', 'other'],
+    'sc': ['one', 'other'],
+    'scn': ['one', 'other'],
     'sd': ['one', 'other'],
     'sdh': ['one', 'other'],
     'se': ['one', 'two', 'other'],
@@ -595,7 +600,7 @@ def get_country_iso_name(country_code):
         if hasattr(country, 'common_name'):
             return country.common_name
         return country.name
-    except KeyError:
+    except (KeyError, AttributeError):
         return u""
 
 
@@ -609,7 +614,7 @@ def get_language_iso_name(language_code):
         if hasattr(language, 'common_name'):
             return language.common_name
         return language.name
-    except KeyError:
+    except (KeyError, AttributeError):
         return u""
 
 
