@@ -1,7 +1,6 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2013 Zuza Software Foundation
+# Copyright 2013, 2016 Zuza Software Foundation
 #
 # This file is part of translate.
 #
@@ -23,6 +22,8 @@
 .. seealso:: http://en.wikipedia.org/wiki/Lao_language
 """
 
+from __future__ import unicode_literals
+
 from translate.lang import common
 
 
