@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
@@ -23,6 +22,8 @@
 .. seealso:: http://en.wikipedia.org/wiki/N'Ko_language
 """
 
+from __future__ import unicode_literals
+
 import re
 
 from translate.lang import common
@@ -30,23 +31,25 @@ from translate.lang import common
 
 def reverse_quotes(text):
     def convertquotation(match):
-        return u"”%s“" % match.group(1)
-    return re.sub(u'“([^”]+)”', convertquotation, text)
+        return "”%s“" % match.group(1)
+    return re.sub('“([^”]+)”', convertquotation, text)
 
 
 class nqo(common.Common):
     """This class represents N'Ko."""
 
-    listseperator = u"߸ "
+    listseperator = "߸ "
 
     puncdict = {
-        u",": u"߸",
-        u";": u"؛",
-        u"?": u"؟",
-        u"!": u"߹",
+        ",": "߸",
+        ";": "؛",
+        "?": "؟",
+        "!": "߹",
     }
 
-    ignoretests = ["startcaps", "simplecaps", "acronyms"]
+    ignoretests = {
+        'all': ["acronyms", "simplecaps", "startcaps"],
+    }
 
     @classmethod
     def punctranslate(cls, text):
