@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
@@ -21,24 +20,27 @@
 """Module to guess the language ISO code based on the 'Language-Team' entry in
 the header of a Gettext PO file.
 """
+from __future__ import print_function, unicode_literals
 
 import re
 
+import six
 
-__all__ = ['LANG_TEAM_CONTACT_SNIPPETS', 'guess_language']
+
+__all__ = ('LANG_TEAM_CONTACT_SNIPPETS', 'guess_language')
 
 LANG_TEAM_REGEX = (
-   ("@li.org", "([a-z_A-Z]{2,})@li.org", ["LL", "XX", "TEAM"]),
-   ("translation-team",
-    "translation-team-([a-z_A-Z]+)@lists.sourceforge.net", None),
-   ("fedora-trans", "fedora-trans-([a-z_A-Z]+)@redhat.com", ["list"]),
-   ("ubuntu-l10n", "ubuntu-l10n-([a-z_A-Z]+)@lists.ubuntu.com", None),
-   ("translate-discuss",
-    "translate-discuss-([a-z_A-Z]+)@lists.sourceforge.net", None),
-   ("kde-i18n", "kde-i18n-([a-z_A-Z]+)@(?:lists\.|mail\.|)kde.org", ["doc"]),
-   ("kde-l10n", "kde-l10n-([a-z_A-Z]+)@kde.org", None),
-   ("fedoraproject", "trans-([a-z_A-Z]+)@lists.fedoraproject.org", None),
-   ("gnome.org", "gnome-([a-z_A-Z]+)-list@gnome.org", ["latin"]),
+    ("@li.org", "([a-z_A-Z]{2,})@li.org", ["LL", "XX", "TEAM"]),
+    ("translation-team",
+     "translation-team-([a-z_A-Z]+)@lists.sourceforge.net", None),
+    ("fedora-trans", "fedora-trans-([a-z_A-Z]+)@redhat.com", ["list"]),
+    ("ubuntu-l10n", "ubuntu-l10n-([a-z_A-Z]+)@lists.ubuntu.com", None),
+    ("translate-discuss",
+     "translate-discuss-([a-z_A-Z]+)@lists.sourceforge.net", None),
+    ("kde-i18n", "kde-i18n-([a-z_A-Z]+)@(?:lists\.|mail\.|)kde.org", ["doc"]),
+    ("kde-l10n", "kde-l10n-([a-z_A-Z]+)@kde.org", None),
+    ("fedoraproject", "trans-([a-z_A-Z]+)@lists.fedoraproject.org", None),
+    ("gnome.org", "gnome-([a-z_A-Z]+)-list@gnome.org", ["latin"]),
 )
 """Data for regular expression based extraction.  The fieds are: prefilter
 information, regex with single group that contains the language code,
@@ -51,7 +53,7 @@ LANG_TEAM_CONTACT_SNIPPETS = {
     "as": ("assam@mm.assam-glug.org", ),
     "ast": ("@softastur.org", "launchpad.net/~ubuntu-l10n-ast",
             "softast-xeneral@lists.sourceforge.net", "Softastur",),
-    "az": ("linuxaz@azerimal.net", "gnome@azitt.com", u"gnome@azətt.com",),
+    "az": ("linuxaz@azerimal.net", "gnome@azitt.com", "gnome@azətt.com",),
     "az_IR": ("az-ir@lists.sharif.edu",),
     "be": ("i18n@mova.org", "i18n@tut.by", "mozilla_byx@poczta.fm",),
     "be@latin": ("translation-team-be-latin@lists", "be-latin.open-tran.eu",),
@@ -185,6 +187,7 @@ LANG_TEAM_CONTACT_SNIPPETS = {
            "debian-l10n-romanian@lists.debian.org", ),
     "ru": ("pgsql-rus@yahoogroups.com", "debian-l10n-russian@lists.debian.org",
            "gnupg-ru@gnupg.org", ),
+    "scn": ("l10n@cademiasiciliana.org", ),
     "sk": ("sk-i18n@lists.linux.sk", "kde-sk@linux.sk", ),
     "sl": ("gnome-si@googlegroups.com", ),
     "sq": ("gnome-albanian-perkthyesit@lists.sourceforge.net",
@@ -230,7 +233,7 @@ LANG_TEAM_LANGUAGE_SNIPPETS = {
     "ar": ("Arabic", ),
     "as": ("Assamese", ),
     "ast": ("Asturian", ),
-    "az": ("Azerbaijani", u"Azərbaycan", ),
+    "az": ("Azerbaijani", "Azərbaycan", ),
     "bg": ("Bulgarian", ),
     "be@latin": ("Belarusian Latin", ),
     "be": ("Belarusian", "Belorussian", ),
@@ -250,13 +253,13 @@ LANG_TEAM_LANGUAGE_SNIPPETS = {
     "el": ("Greek", ),
     "en_GB": ("British English", "en_GB", "English (Great Britain)", ),
     "eo": ("Esperanto", ),
-    "es": ("Spanish", "es_ES", u"Español", ),
+    "es": ("Spanish", "es_ES", "Español", ),
     "et": ("Eesti", "Estonian", ),
     "eu": ("Basque", "Euskara", ),
     "fa": ("Persian", ),
     "fi": ("Finnish", "Suomi", ),
     "fo": ("Faroese", ),
-    "fr": ("French", u"Français", ),
+    "fr": ("French", "Français", ),
     "fur": ("Friulian", ),
     "ga": ("Irish", ),
     "gez": ("Geez", ),
@@ -286,7 +289,7 @@ LANG_TEAM_LANGUAGE_SNIPPETS = {
     "lg": ("Luganda", ),
     "li": ("Limburgish", ),
     "lt": ("Lithuanian", ),
-    "lv": ("Latvian", "lv_LV", "Valoda", u"Latviešu", ),
+    "lv": ("Latvian", "lv_LV", "Valoda", "Latviešu", ),
     "mal": ("Malayalam", ),
     "mg": ("Malagasy", ),
     "mi": ("Maori", ),
@@ -296,8 +299,8 @@ LANG_TEAM_LANGUAGE_SNIPPETS = {
     "mt": ("Marathi", ),
     "ms": ("Malay", "Bahasa Melayu", ),
     "my": ("Burmese", ),
-    "nb": ("Norwegian Bokmaal", u"Norsk bokmål", u"Norwegian Bokmål",
-           u"Norwegian bokmål", ),
+    "nb": ("Norwegian Bokmaal", "Norsk bokmål", "Norwegian Bokmål",
+           "Norwegian bokmål", ),
     "nds": ("Low Saxon", ),
     "nl": ("Dutch", "Nederlands", ),
     "nn": ("Norwegian nynorsk", "Nynorsk", ),
@@ -306,12 +309,13 @@ LANG_TEAM_LANGUAGE_SNIPPETS = {
     "pa": ("Punjabi", "Panjabi", ),
     "pl": ("Polish", ),
     "ps": ("Pashto", "Pushto", ),
-    "pt_BR": ("Brazilian Portuguese", u"Português/Brasil",
-              u"Português do Brasil", ),
+    "pt_BR": ("Brazilian Portuguese", "Português/Brasil",
+              "Português do Brasil", ),
     "pt": ("Portuguese", ),
     "rm": ("Rhaeto-Romance", ),
-    "ro": ("Romania", "Romanian", u"Română", ),
+    "ro": ("Romania", "Romanian", "Română", ),
     "ru": ("Russian", ),
+    "scn": ("Sicilian", "Sicilianu", "Siciliano", ),
     "si": ("Sinhala", "Sinhalese", ),
     "sk": ("Slovak", ),
     "sl": ("Slovene", "Slovenian", ),
@@ -328,13 +332,13 @@ LANG_TEAM_LANGUAGE_SNIPPETS = {
     "ti": ("Tigrinya", ),
     "tig": ("Tigre", ),
     "tl": ("Tagalog", ),
-    "tr": ("Turkish", u"Türkçe", u"Türkiye", ),
+    "tr": ("Turkish", "Türkçe", "Türkiye", ),
     "tt": ("Tatarish", ),
     "ug": ("Uighur", ),
     "uk": ("Ukrainian", ),
     "ur": ("Urdu", ),
     "uz": ("Uzbek", ),
-    "ve": ("Venda", u"Tshivenḓa", "Tshivenda", ),
+    "ve": ("Venda", "Tshivenḓa", "Tshivenda", ),
     "vi": ("Vietnamese", ),
     "wa": ("Walloon", ),
     "wal": ("Walamo", ),
@@ -402,7 +406,7 @@ def _snippet_guesser(snippets_dict, string, filter_=_nofilter):
     before examination
     """
     string = filter_(string)
-    for possible_lang, snippets in snippets_dict.iteritems():
+    for possible_lang, snippets in six.iteritems(snippets_dict):
         for snippet in snippets:
             if filter_(snippet) in string:
                 return possible_lang
@@ -427,13 +431,14 @@ def guess_language(team_string):
     # TODO Maybe clean everything and see of we have a language code only
 
     if not lang:
-        #print (u"MISSED: '%s'" % team_string).encode('utf-8')
+        #print ("MISSED: '%s'" % team_string).encode('utf-8')
         return None
     return lang
 
+
 if __name__ == "__main__":
     from sys import argv
     from translate.storage import factory
     for fname in argv[1:]:
         store = factory.getobject(fname)
-        print(fname, guess_language(store.parseheader().get('Language-Team', u"")))
+        print(fname, guess_language(store.parseheader().get('Language-Team', "")))
