@@ -255,7 +255,7 @@ class Dialect(object):
         """Encode the string"""
         # FIXME: dialects are a bad idea, not possible for subclasses
         # to override key methods
-        if encoding != "utf-8":
+        if encoding not in ("utf-8", "utf-16"):
             return quote.javapropertiesencode(string or u"")
         return quote.java_utf8_properties_encode(string or u"")
 
@@ -355,6 +355,17 @@ class DialectJavaUtf8(DialectJava):
         return quote.java_utf8_properties_encode(string or u"")
 
 
+@register_dialect
+class DialectJavaUtf16(DialectJava):
+    name = "java-utf16"
+    default_encoding = "utf-16"
+    delimiters = [u"=", u":", u" "]
+
+    @classmethod
+    def encode(cls, string, encoding=None):
+        return quote.java_utf8_properties_encode(string or u"")
+
+
 @register_dialect
 class DialectFlex(DialectJava):
     name = "flex"
@@ -593,7 +604,7 @@ class propunit(base.TranslationUnit):
         else:
             return super(propunit, self).getnotes(origin)
 
-    def removenotes(self):
+    def removenotes(self, origin=None):
         self.comments = []
 
     def isblank(self):
@@ -634,7 +645,7 @@ class propfile(base.TranslationStore):
         text, encoding = self.detect_encoding(
             propsrc, default_encodings=[self.personality.default_encoding,
                                         'utf-8', 'utf-16'])
-        if not text:
+        if not text and propsrc:
             raise IOError("Cannot detect encoding for %s." % (self.filename or
                                                               "given string"))
         self.encoding = encoding
@@ -643,6 +654,7 @@ class propfile(base.TranslationStore):
         newunit = propunit("", self.personality.name)
         inmultilinevalue = False
         inmultilinecomment = False
+        was_header = False
 
         for line in propsrc.split(u"\n"):
             # handle multiline value if we're in one
@@ -674,9 +686,16 @@ class propfile(base.TranslationStore):
                     inmultilinecomment = False
             elif not line.strip():
                 # this is a blank line...
-                if str(newunit).strip():
+                # avoid adding comment only units
+                if newunit.name:
                     self.addunit(newunit)
                     newunit = propunit("", self.personality.name)
+                elif not was_header and str(newunit).strip():
+                    self.addunit(newunit)
+                    newunit = propunit("", self.personality.name)
+                    was_header = True
+                elif newunit.comments:
+                    newunit.comments.append("")
             else:
                 newunit.delimiter, delimiter_pos = self.personality.find_delimiter(line)
                 if delimiter_pos == -1:
@@ -728,6 +747,16 @@ class javautf8file(propfile):
         super(javautf8file, self).__init__(*args, **kwargs)
 
 
+class javautf16file(propfile):
+    Name = "Java Properties (UTF-16)"
+    Extensions = ['properties']
+
+    def __init__(self, *args, **kwargs):
+        kwargs['personality'] = "java-utf16"
+        kwargs['encoding'] = "utf-16"
+        super(javautf8file, self).__init__(*args, **kwargs)
+
+
 class stringsfile(propfile):
     Name = "OS X Strings"
     Extensions = ['strings']
