@@ -54,15 +54,24 @@ def splitlines(text):
     Can not use univerzal newlines as they match any newline like
     character inside text and that breaks on files with unix newlines
     and LF chars inside comments.
+
+    The code looks for first msgid and looks for newline used after it. This
+    should safely cover weird newlines used in comments or filenames, while
+    properly parsing po files with any newlines.
     """
+    # Strip UTF-8 BOM if present. This file would not be accepted
+    # by gettext, but some editors might create it, so better handle it.
+    if text[:3] == b'\xEF\xBB\xBF':
+        text = text[3:]
     # Find first newline
     newline = b'\n'
-    for i, ch in enumerate(text):
+    msgid_pos = max(0, text.find(b'msgid'))
+    for i, ch in enumerate(text[msgid_pos:]):
         # Iteration over bytes yields numbers in Python 3
         if ch in ('\n', 10):
             break
         if ch in ('\r', 13):
-            if text[i + 1] in ('\n', 10):
+            if text[msgid_pos + i + 1] in ('\n', 10):
                 newline = b'\r\n'
             else:
                 newline = b'\r'
@@ -370,12 +379,12 @@ class pounit(pocommon.pounit):
         :param origin: programmer, developer, source code, translator or None
         """
         if origin is None:
-            comments = u"".join([comment[2:] for comment in self.othercomments])
-            comments += u"".join([comment[3:] for comment in self.automaticcomments])
+            comments = u"".join([comment[2:] or "\n" for comment in self.othercomments])
+            comments += u"".join([comment[3:] or "\n" for comment in self.automaticcomments])
         elif origin == "translator":
-            comments = u"".join([comment[2:] for comment in self.othercomments])
+            comments = u"".join([comment[2:] or "\n" for comment in self.othercomments])
         elif origin in ["programmer", "developer", "source code"]:
-            comments = u"".join([comment[3:] for comment in self.automaticcomments])
+            comments = u"".join([comment[3:] or "\n" for comment in self.automaticcomments])
         else:
             raise ValueError("Comment type not valid")
         # Let's drop the last newline
@@ -409,7 +418,7 @@ class pounit(pocommon.pounit):
         else:
             self.othercomments = newcomments
 
-    def removenotes(self):
+    def removenotes(self, origin=None):
         """Remove all the translator's notes (other comments)"""
         self.othercomments = []
 
@@ -544,15 +553,21 @@ class pounit(pocommon.pounit):
         # Before, the equivalent of the following was the final return statement:
         # return len(self.source.strip()) == 0
 
-    def hastypecomment(self, typecomment):
+    def _extracttypecomment(self):
+        for tc in self.typecomments:
+            for flag in tc.split(","):
+                value = flag.strip()
+                if not value or value == '#':
+                    continue
+                yield value
+
+    def hastypecomment(self, typecomment, parsed=None):
         """Check whether the given type comment is present"""
         if not self.typecomments:
             return False
-        for tc in self.typecomments:
-            # check for word boundaries properly by using a regular expression
-            if re.search("\\b%s\\b" % typecomment, tc):
-                return True
-        return False
+        if not parsed:
+            parsed = self._extracttypecomment()
+        return typecomment in parsed
 
     def hasmarkedcomment(self, commentmarker):
         """Check whether the given comment marker is present.
@@ -569,8 +584,8 @@ class pounit(pocommon.pounit):
 
     def settypecomment(self, typecomment, present=True):
         """Alters whether a given typecomment is present"""
-        if self.hastypecomment(typecomment) != present:
-            typecomments = re.findall(r"\b[-\w]+\b", "\n".join(self.typecomments))
+        typecomments = list(self._extracttypecomment())
+        if self.hastypecomment(typecomment, typecomments) != present:
             if present:
                 typecomments.append(typecomment)
             else:
@@ -655,6 +670,9 @@ class pounit(pocommon.pounit):
                     #Before we used to strip. Necessary in some cases?
                     combinedcomment.append(comment)
                 partcomments = self.quote("_:%s" % "".join(combinedcomment))
+                # Strip heading empty line for multiline string, it was already added above
+                if partcomments[0] == '""':
+                    partcomments = partcomments[1:]
             # comments first, no blank leader line needed
             partstr += "\n".join(partcomments)
             partstr = quote.rstripeol(partstr)
@@ -662,7 +680,12 @@ class pounit(pocommon.pounit):
             partstr += '""'
         partstr += '\n'
         # add the rest
+        previous = None
         for partline in partlines[partstartline:]:
+            # Avoid duplicate empty lines
+            if previous == '""' and partline == '""':
+                continue
+            previous = partline
             partstr += partline + '\n'
         return partstr
 
