@@ -29,6 +29,7 @@
 import re
 import six
 
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
@@ -63,24 +64,35 @@ class rcunit(base.TranslationUnit):
         self.source = source
         self.match = None
 
-    def setsource(self, source):
+    @property
+    def source(self):
+        return self._value
+
+    @source.setter
+    def source(self, source):
         """Sets the source AND the target to be equal"""
         self._rich_source = None
         self._value = source or ""
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
     def getsource(self):
-        return self._value
+        return self.source
 
-    source = property(getsource, setsource)
+    @property
+    def target(self):
+        return self.source
 
-    def settarget(self, target):
+    @target.setter
+    def target(self, target):
         """.. note:: This also sets the ``.source`` attribute!"""
         self._rich_target = None
         self.source = target
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
     def gettarget(self):
-        return self.source
-    target = property(gettarget, settarget)
+        return self.target
 
     def __str__(self):
         """Convert to a string."""
@@ -102,7 +114,7 @@ class rcunit(base.TranslationUnit):
     def getnotes(self, origin=None):
         return '\n'.join(self.comments)
 
-    def removenotes(self):
+    def removenotes(self, origin=None):
         self.comments = []
 
     def isblank(self):
@@ -125,6 +137,7 @@ class rcfile(base.TranslationStore):
         if inputfile is not None:
             rcsrc = inputfile.read().decode(self.encoding)
             inputfile.close()
+            rcsrc = rcsrc.replace('\r', '')
             self.parse(rcsrc)
 
     def parse(self, rcsrc):
