@@ -23,7 +23,8 @@
 from lxml import etree
 
 from translate.lang import data
-from translate.misc.xml_helpers import setXMLspace
+from translate.misc.deprecation import deprecated
+from translate.misc.xml_helpers import setXMLspace, reindent
 from translate.storage import base, lisa
 from translate.storage.placeables import general
 
@@ -48,36 +49,43 @@ class RESXUnit(lisa.LISAunit):
     def _gettargetnode(self):
         return self.xmlelement.find(self.namespaced(self.languageNode))
 
-    def getsource(self):
+    @lisa.LISAunit.source.getter
+    def source(self):
         return self.target
 
-    def settarget(self, text, lang='xx', append=False):
-        # Firstly deal with reinitialising to None or setting to identical
-        # string.
-        self._rich_target = None
-        if self.target == text:
-            return
-        strings = []
-        if isinstance(text, list):
-            strings = text
-        else:
-            strings = [text]
-        targetnode = self._gettargetnode()
-        targetnode.clear()
-        targetnode.text = data.forceunicode(text) or u""
-        # Assume no <comment> follows; allow the </data> element
-        # to be indented with 2 spaces (same level as the opening
-        # <data> element before <value>)
-        targetnode.tail = u"\n  "
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
-    def gettarget(self, lang=None):
+    @property
+    def target(self):
         targetnode = self._gettargetnode()
         if targetnode is None:
             etree.SubElement(self.xmlelement, self.namespaced("value"))
             return None
         return data.forceunicode(targetnode.text) or u""
-    target = property(gettarget, settarget)
-    rich_target = property(base.TranslationUnit._get_rich_target, base.TranslationUnit._set_rich_target)
+
+    @target.setter
+    def target(self, target):
+        # Firstly deal with reinitialising to None or setting to identical
+        # string.
+        self._rich_target = None
+        if self.target == target:
+            return
+        targetnode = self._gettargetnode()
+        targetnode.clear()
+        targetnode.text = data.forceunicode(target) or u""
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def gettarget(self):
+        return self.target
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def settarget(self, target):
+        self.target = target
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in the appropriate "comment" tag"""
@@ -99,10 +107,6 @@ class RESXUnit(lisa.LISAunit):
             # Correct the indent of <comment> by updating the tail of
             # the preceding <value> element
             targetnode = self._gettargetnode()
-            targetnode.tail = u"\n    "
-        # This also requires putting a matching tail on the <comment>,
-        # otherwise the </data> would yet again be misaligned
-        note.tail = u"\n  "
 
     def getnotes(self, origin=None):
         comments = []
@@ -225,4 +229,25 @@ class RESXFile(lisa.LISAfile):
         if unit.getid() is None:
             self._messagenum += 1
             unit.setid(u"%s" % unit.source.strip(' '))
+        # adjust the current and previous elements for new ones;
+        # otherwise they will not be indented correctly.
+        if new:
+            previous_node = unit.xmlelement.getprevious()
+            if previous_node is None:
+                # this is the first element; adjust root.
+                # should not happen in a ResX file prepared by Visual Studio
+                # since it includes an inline XSD plus resheader at all times.
+                self.body.text = u"\n  "
+            # adjust the indent of the following <value> element
+            unit.xmlelement.text = u"\n    "
         return unit
+
+    def serialize(self, out=None):
+        root = self.document.getroot()
+        reindent(root, indent="  ", max_level=4)
+        # Use same header as Visual Studio
+        out.write(b'<?xml version="1.0" encoding="utf-8"?>\n')
+        content = etree.tostring(root, pretty_print=False, xml_declaration=False,
+                                 encoding='utf-8')
+        # Additional space on empty tags same as Visual Studio
+        out.write(content.replace(b'/>', b' />'))
