@@ -1,6 +1,5 @@
-#!/usr/bin/env python
-
 """Tests for the directory module"""
+from __future__ import print_function
 
 import os
 
@@ -35,10 +34,9 @@ class TestDirectory(object):
 
     def touchfiles(self, dir, filenames, content=None):
         for filename in filenames:
-            f = open(os.path.join(dir, filename), "w")
-            if content:
-                f.write(content)
-            f.close()
+            with open(os.path.join(dir, filename), "w") as fh:
+                if content:
+                    fh.write(content)
 
     def mkdir(self, dir):
         """Makes a directory inside self.testdir."""
