@@ -1,6 +1,8 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+from __future__ import unicode_literals
+
+import six
 from pytest import mark, raises
 
 from translate.misc import wStringIO
@@ -68,10 +70,10 @@ class TestPOUnit(test_base.TestTranslationUnit):
     def test_adding_empty_note(self):
         unit = self.UnitClass("bla")
         print(str(unit))
-        assert not '#' in str(unit)
+        assert '#' not in str(unit)
         for empty_string in ["", " ", "\t", "\n"]:
             unit.addnote(empty_string)
-            assert not '#' in str(unit)
+            assert '#' not in str(unit)
 
     def test_markreview(self):
         """Tests if we can mark the unit to need review."""
@@ -120,7 +122,7 @@ class TestPOUnit(test_base.TestTranslationUnit):
         assert not unit.hasplural()
 
         # plural test with multistring
-        unit.setsource(["Tree", "Trees"])
+        unit.source = ["Tree", "Trees"]
         assert unit.source.strings == ["Tree", "Trees"]
         assert unit.hasplural()
         unit.target = multistring(["ki", "ni ki"])
@@ -128,7 +130,8 @@ class TestPOUnit(test_base.TestTranslationUnit):
 
         # test of msgid with no plural and msgstr with plural
         unit = self.UnitClass("Tree")
-        assert raises(ValueError, unit.settarget, [u"ki", u"ni ki"])
+        with raises(ValueError):
+            unit.target = [u"ki", u"ni ki"]
         assert not unit.hasplural()
 
     def test_wrapping_bug(self):
@@ -156,6 +159,19 @@ class TestPOUnit(test_base.TestTranslationUnit):
         unit.source = u"Goeiemôre"
         assert not unit.isheader()
 
+    def test_buildfromunit(self):
+        unit = self.UnitClass("test source")
+        unit_copy = self.UnitClass.buildfromunit(unit)
+        assert unit is not unit_copy
+        assert unit == unit_copy
+
+        # Test with a unit without copy() method (will call base.buildfromunit)
+        from translate.storage.php import phpunit
+        unit = phpunit("test source")
+        unit_copy = self.UnitClass.buildfromunit(unit)
+        assert unit is not unit_copy
+        assert unit == unit_copy
+
 #     def test_rich_source(self):
 #         unit = self.unit
 #         unit.rich_source = [['a', X('42'), 'c']]
@@ -178,7 +194,7 @@ class TestPOFile(test_base.TestTranslationStore):
 
     def poregen(self, posource):
         """helper that converts po source to pofile object and back"""
-        return str(self.poparse(posource))
+        return bytes(self.poparse(posource))
 
     def pomerge(self, oldmessage, newmessage, authoritative):
         """helper that merges two messages"""
@@ -200,7 +216,7 @@ class TestPOFile(test_base.TestTranslationStore):
             # force rewrapping:
             u.source = u.source
             u.target = u.target
-        return str(pofile)
+        return bytes(pofile).decode('utf-8')
 
     def test_context_only(self):
         """Checks that an empty msgid with msgctxt is handled correctly."""
@@ -212,7 +228,7 @@ msgstr ""
         assert pofile.units[0].istranslatable()
         assert not pofile.units[0].isheader()
         # we were not generating output for thse at some stage
-        assert str(pofile)
+        assert bytes(pofile)
 
     def test_simpleentry(self):
         """checks that a simple po entry is parsed correctly"""
@@ -293,7 +309,7 @@ msgstr[1] "Kóeie"
         pofile = self.poparse(posource)
         unit = pofile.units[0]
         assert isinstance(unit.source, multistring)
-        assert isinstance(unit.source.strings[1], unicode)
+        assert isinstance(unit.source.strings[1], six.text_type)
 
     def test_nongettext_location(self):
         """test that we correctly handle a non-gettext (file:linenumber) location"""
@@ -305,15 +321,26 @@ msgstr[1] "Kóeie"
         print(locations)
         assert len(locations) == 1
         assert locations[0] == u"programming/C/programming.xml:44(para)"
-        assert isinstance(locations[0], unicode)
+        assert isinstance(locations[0], six.text_type)
+
+    def test_percent_location(self):
+        """test that we correctly handle a location with percent chars"""
+        posource = '#: /foo/bar/%%var%%www%%about.html:44\nmsgid "test"\nmsgstr "rest"\n'
+        pofile = self.poparse(posource)
+        u = pofile.units[-1]
+
+        locations = u.getlocations()
+        print(locations)
+        assert len(locations) == 1
+        assert locations[0] == "/foo/bar/%%var%%www%%about.html:44"
 
     @mark.xfail(reason="Not Implemented")
     def test_kde_plurals(self):
         """Tests kde-style plurals. (Bug: 191)"""
-        posource = '''msgid "_n Singular\\n"
+        posource = r'''msgid "_n Singular\n"
 "Plural"
-msgstr "Een\\n"
-"Twee\\n"
+msgstr "Een\n"
+"Twee\n"
 "Drie"
 '''
         pofile = self.poparse(posource)
@@ -340,7 +367,7 @@ msgid ""
 msgstr "POT-Creation-Date: 2006-03-08 17:30+0200\n"
 '''
         pofile = self.poparse(posource)
-        assert str(pofile) == posource
+        assert bytes(pofile).decode('utf-8') == posource
 
     def test_fuzzy(self):
         """checks that fuzzy functionality works as expected"""
@@ -351,7 +378,7 @@ msgstr "POT-Creation-Date: 2006-03-08 17:30+0200\n"
         assert pofile.units[0].isfuzzy()
         pofile.units[0].markfuzzy(False)
         assert not pofile.units[0].isfuzzy()
-        assert str(pofile) == expectednonfuzzy
+        assert bytes(pofile).decode('utf-8') == expectednonfuzzy
 
         posource = '#, fuzzy, python-format\nmsgid "ball"\nmsgstr "bal"\n'
         expectednonfuzzy = '#, python-format\nmsgid "ball"\nmsgstr "bal"\n'
@@ -361,10 +388,10 @@ msgstr "POT-Creation-Date: 2006-03-08 17:30+0200\n"
         assert pofile.units[0].isfuzzy()
         pofile.units[0].markfuzzy(False)
         assert not pofile.units[0].isfuzzy()
-        assert str(pofile) == expectednonfuzzy
+        assert bytes(pofile).decode('utf-8') == expectednonfuzzy
         pofile.units[0].markfuzzy()
-        print(str(pofile))
-        assert str(pofile) == expectedfuzzyagain
+        print(bytes(pofile))
+        assert bytes(pofile).decode('utf-8') == expectedfuzzyagain
 
         # test the same, but with flags in a different order
         posource = '#, python-format, fuzzy\nmsgid "ball"\nmsgstr "bal"\n'
@@ -375,11 +402,11 @@ msgstr "POT-Creation-Date: 2006-03-08 17:30+0200\n"
         assert pofile.units[0].isfuzzy()
         pofile.units[0].markfuzzy(False)
         assert not pofile.units[0].isfuzzy()
-        print(str(pofile))
-        assert str(pofile) == expectednonfuzzy
+        print(bytes(pofile))
+        assert bytes(pofile).decode('utf-8') == expectednonfuzzy
         pofile.units[0].markfuzzy()
-        print(str(pofile))
-        assert str(pofile) == expectedfuzzyagain
+        print(bytes(pofile))
+        assert bytes(pofile).decode('utf-8') == expectedfuzzyagain
 
     @mark.xfail(reason="Check differing behaviours between pypo and cpo")
     def test_makeobsolete_untranslated(self):
@@ -387,7 +414,7 @@ msgstr "POT-Creation-Date: 2006-03-08 17:30+0200\n"
         posource = '#. The automatic one\n#: test.c\nmsgid "test"\nmsgstr ""\n'
         pofile = self.poparse(posource)
         unit = pofile.units[0]
-        print(str(pofile))
+        print(bytes(pofile))
         assert not unit.isobsolete()
         unit.makeobsolete()
         assert str(unit) == ""
@@ -445,7 +472,7 @@ msgstr "tweede"
         assert len(pofile.units) == 1
         unit = pofile.units[0]
         assert unit.isobsolete()
-        assert str(pofile) == posource
+        assert bytes(pofile).decode('utf-8') == posource
 
         posource = '''msgid "one"
 msgstr "een"
@@ -461,9 +488,9 @@ msgstr "een"
         unit = pofile.units[1]
         assert unit.isobsolete()
 
-        print(str(pofile))
+        print(bytes(pofile))
         # Doesn't work with CPO if obsolete units are mixed with non-obsolete units
-        assert str(pofile) == posource
+        assert bytes(pofile).decode('utf-8') == posource
         unit.resurrect()
         assert unit.hasplural()
 
@@ -497,13 +524,13 @@ msgstr "een"
         assert not unit.istranslatable()
 
         print(posource)
-        print(str(pofile))
-        assert str(pofile) == posource
+        print(bytes(pofile))
+        assert bytes(pofile).decode('utf-8') == posource
 
     def test_header_escapes(self):
         pofile = self.StoreClass()
         pofile.updateheader(add=True, **{"Report-Msgid-Bugs-To": r"http://qa.openoffice.org/issues/enter_bug.cgi?subcomponent=ui&comment=&short_desc=Localization%20issue%20in%20file%3A%20dbaccess\source\core\resource.oo&component=l10n&form_name=enter_issue"})
-        filecontents = str(pofile)
+        filecontents = bytes(pofile).decode('utf-8')
         print(filecontents)
         # We need to make sure that the \r didn't get misrepresented as a
         # carriage return, but as a slash (escaped) followed by a normal 'r'
@@ -581,15 +608,14 @@ msgstr[1] "Koeie"
         assert len(pofile.units) == 1
         unit = pofile.units[0]
         assert unit.isobsolete()
-        print(str(pofile))
+        print(bytes(pofile))
         print(posource)
-        assert str(pofile) == posource
+        assert bytes(pofile).decode('utf-8') == posource
 
     def test_merge_duplicates(self):
         """checks that merging duplicates works"""
         posource = '#: source1\nmsgid "test me"\nmsgstr ""\n\n#: source2\nmsgid "test me"\nmsgstr ""\n'
         pofile = self.poparse(posource)
-        #assert len(pofile.units) == 2
         pofile.removeduplicates("merge")
         assert len(pofile.units) == 1
         assert pofile.units[0].getlocations() == ["source1", "source2"]
@@ -608,9 +634,9 @@ msgid "test"
 msgstr ""
 '''
         pofile = self.poparse(posource)
-        print(str(pofile))
+        print(bytes(pofile))
         pofile.removeduplicates("merge")
-        print(str(pofile))
+        print(bytes(pofile))
         assert len(pofile.units) == 1
         assert pofile.units[0].getlocations() == ["source1", "source2"]
 
@@ -676,10 +702,10 @@ msgstr "omskakel"
 
     def test_kde_context(self):
         """Tests that kde-style msgid comments can be retrieved via getcontext()."""
-        posource = '''# Test comment
+        posource = r'''# Test comment
 #: source1
 msgid ""
-"_: Noun\\n"
+"_: Noun\n"
 "convert"
 msgstr "bekeerling"
 
@@ -687,7 +713,7 @@ msgstr "bekeerling"
 #: source2
 msgid ""
 "_: Verb. _: "
-"The action of changing.\\n"
+"The action of changing.\n"
 "convert"
 msgstr "omskakel"
 '''
@@ -765,9 +791,9 @@ msgstr "b"
 '''
         pofile = self.poparse(posource)
         for line in pofile.units[0].getnotes():
-            assert isinstance(line, unicode)
+            assert isinstance(line, six.text_type)
 
-    def test_non_ascii_header_comments(self):
+    def test_non_ascii_header_comments_2(self):
         posource = r'''
 # Copyright bla.
 msgid ""
@@ -787,7 +813,6 @@ msgstr "b"
         assert u"Last-Translator" in header_dict
         assert header_dict[u"Last-Translator"] == u"Tránslátór"
 
-
         # let's test the same with latin-1:
         posource = r'''
 # Copyright bla.
@@ -801,7 +826,7 @@ msgstr ""
 
 msgid "a"
 msgstr "b"
-'''.decode('utf-8').encode('ISO-8859-1')
+'''.encode('ISO-8859-1')
 
         pofile = self.poparse(posource)
         assert u"Tránslátór" in pofile.units[0].target
@@ -810,7 +835,7 @@ msgstr "b"
         assert header_dict[u"Last-Translator"] == u"Tránslátór"
 
     def test_final_slash(self):
-        """Test that \ as last character is correcly interpreted (bug 960)."""
+        """Test that \\ as last character is correcly interpreted (bug 960)."""
         posource = r'''
 msgid ""
 msgstr ""
@@ -823,9 +848,9 @@ msgstr "プロジェクトが見つかりませんでした"
         pofile1 = self.poparse(posource)
         print(pofile1.units[1].source)
         assert pofile1.units[1].source == u"I cannot locate the project\\"
-        pofile2 = self.poparse(str(pofile1))
-        print(str(pofile2))
-        assert str(pofile1) == str(pofile2)
+        pofile2 = self.poparse(bytes(pofile1))
+        print(bytes(pofile2))
+        assert bytes(pofile1) == bytes(pofile2)
 
     def test_unfinished_lines(self):
         """Test that we reasonably handle lines with a single quote."""
@@ -842,13 +867,13 @@ msgstr "start thing dingis fish"
         pofile1 = self.poparse(posource)
         print(repr(pofile1.units[1].target))
         assert pofile1.units[1].target == u"start thing dingis fish"
-        pofile2 = self.poparse(str(pofile1))
+        pofile2 = self.poparse(bytes(pofile1))
         assert pofile2.units[1].target == u"start thing dingis fish"
-        print(str(pofile2))
-        assert str(pofile1) == str(pofile2)
+        print(bytes(pofile2))
+        assert bytes(pofile1) == bytes(pofile2)
 
     def test_encoding_change(self):
-        posource = ur'''
+        posource = r'''
 msgid ""
 msgstr ""
 "PO-Revision-Date: 2006-02-09 23:33+0200\n"
@@ -858,17 +883,19 @@ msgstr ""
 
 msgid "a"
 msgstr "d"
-'''.encode('iso-8859-1')
+'''
+        if six.PY3:
+            posource = posource.encode('utf-8')
         pofile = self.poparse(posource)
         unit = pofile.units[1]
         unit.target = u"ḓ"
-        contents = str(pofile)
-        assert 'msgstr "\341\270\223"' in contents
-        assert 'charset=UTF-8' in contents
+        contents = bytes(pofile)
+        assert b'msgstr "\xe1\xb8\x93"' in contents
+        assert b'charset=UTF-8' in contents
 
     def test_istranslated(self):
         """checks that istranslated works ok."""
-        posource = ur'''
+        posource = r'''
 msgid ""
 msgstr ""
 "PO-Revision-Date: 2006-02-09 23:33+0200\n"
@@ -880,6 +907,8 @@ msgid "a"
 msgid_plural "aa"
 msgstr[0] ""
 '''
+        if six.PY2:
+            posource = posource.decode('utf-8')
         pofile = self.poparse(posource)
         unit = pofile.units[1]
         print(str(unit))
@@ -962,7 +991,7 @@ msgstr ""
 '''
         assert self.poreflow(posource) == posource_wanted
 
-        posource =r'''#: 10
+        posource = r'''#: 10
 msgid "\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\"
 msgstr "\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\"
 '''
@@ -974,3 +1003,44 @@ msgstr ""
 "\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\"
 "\\"
 '''
+
+    def test_msgidcomments(self):
+        posource = r'''
+msgid ""
+msgstr ""
+"PO-Revision-Date: 2006-02-09 23:33+0200\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=ISO-8859-1\n"
+"Content-Transfer-Encoding: 8-bit\n"
+
+# the one in the msgid should be "swallowed", but not in msgstr
+msgid ""
+"_: An archaic KDE context comment\n"
+"The actual source text"
+msgstr ""
+"_: I'll be clever and translate in a text editor and duplicate the KDE comment"
+'''
+        if six.PY2:
+            posource = posource.decode('utf-8')
+        pofile = self.poparse(posource)
+        unit = pofile.units[1]
+        assert unit.source == u'The actual source text'
+        assert unit.target.startswith(u'_: ')
+
+    def test_unicode(self):
+        posource = b'''
+msgid ""
+msgstr ""
+"Content-Type: application/x-publican; charset=UTF-8\\n"
+
+msgid "Rapha\xc3\xabl"
+msgstr ""
+
+msgid "Rapha\xc3\xabl2"
+msgstr ""
+'''
+        pofile = self.poparse(posource)
+        unit = pofile.units[2]
+        assert unit.source == u'Raphaël2'
+        unit = pofile.units[1]
+        assert unit.source == u'Raphaël'
