@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 
 import six
 from pytest import raises
@@ -120,7 +120,8 @@ class TestPYPOUnit(test_po.TestPOUnit):
         assert unit.getnotes("developer") == "Verb"
         assert unit.getnotes("translator") == "Which meaning of file?\nThank you"
         assert unit.getnotes() == "Which meaning of file?\nThank you\nVerb"
-        assert raises(ValueError, unit.getnotes, "devteam")
+        with raises(ValueError):
+            unit.getnotes("devteam")
 
     def test_notes_withcomments(self):
         """tests that when we add notes that look like comments that we treat them properly"""
@@ -136,13 +137,11 @@ class TestPYPOUnit(test_po.TestPOUnit):
         str_max = "123456789 123456789 123456789 123456789 123456789 123456789 123456789 1"
         unit = self.UnitClass(str_max)
         expected = 'msgid "%s"\nmsgstr ""\n' % str_max
-        print(expected, str(unit))
         assert str(unit) == expected
         # at this length we wrap
         str_wrap = str_max + '2'
         unit = self.UnitClass(str_wrap)
         expected = 'msgid ""\n"%s"\nmsgstr ""\n' % str_wrap
-        print(expected, str(unit))
         assert str(unit) == expected
 
     def test_wrap_on_newlines(self):
@@ -151,7 +150,6 @@ class TestPYPOUnit(test_po.TestPOUnit):
         postring = ('"123456789\\n"\n' * 3)[:-1]
         unit = self.UnitClass(string)
         expected = 'msgid ""\n%s\nmsgstr ""\n' % postring
-        print(expected, str(unit))
         assert str(unit) == expected
 
         # Now check for long newlines segments
@@ -166,7 +164,6 @@ class TestPYPOUnit(test_po.TestPOUnit):
 msgstr ""
 '''
         unit = self.UnitClass(longstring)
-        print(expected, str(unit))
         assert str(unit) == expected
 
     def test_wrap_on_max_line_length(self):
@@ -174,10 +171,17 @@ msgstr ""
         string = "1 3 5 7 N " * 11
         expected = 'msgid ""\n%s\nmsgstr ""\n' % '"1 3 5 7 N 1 3 5 7 N 1 3 5 7 N 1 3 5 7 N 1 3 5 7 N 1 3 5 7 N 1 3 5 7 N 1 3 5 "\n"7 N 1 3 5 7 N 1 3 5 7 N 1 3 5 7 N "'
         unit = self.UnitClass(string)
-        print("Expected:")
-        print(expected)
-        print("Actual:")
-        print(str(unit))
+        assert str(unit) == expected
+
+    def test_wrap_on_slash(self):
+        """test that we wrap on /"""
+        string = "1/3/5/7/N/" * 11
+        expected = '''msgid ""
+"1/3/5/7/N/1/3/5/7/N/1/3/5/7/N/1/3/5/7/N/1/3/5/7/N/1/3/5/7/N/1/3/5/7/N/1/3/5/"
+"7/N/1/3/5/7/N/1/3/5/7/N/1/3/5/7/N/"
+msgstr ""
+'''
+        unit = self.UnitClass(string)
         assert str(unit) == expected
 
     def test_spacing_max_line(self):
@@ -190,10 +194,6 @@ msgstr ""
 msgstr ""
 '''
         unit = self.UnitClass(idstring)
-        print("Expected:")
-        print(expected)
-        print("Actual:")
-        print(str(unit))
         assert str(unit) == expected
 
 
@@ -228,8 +228,6 @@ class TestPYPOFile(test_po.TestPOFile):
         assert len(pofile.units) == 2
         pofile.removeduplicates("merge")
         assert len(pofile.units) == 2
-        print(pofile.units[0].msgidcomments)
-        print(pofile.units[1].msgidcomments)
         assert pypo.unquotefrompo(pofile.units[0].msgidcomments) == "_: source1\n"
         assert pypo.unquotefrompo(pofile.units[1].msgidcomments) == "_: source2\n"
 
@@ -264,6 +262,26 @@ class TestPYPOFile(test_po.TestPOFile):
         assert pofile.units[0].sourcecomments == ["#: source comment\n"]
         assert pofile.units[0].typecomments == ["#, fuzzy\n"]
 
+    def test_typecomments(self):
+        """test typecomments handling"""
+        posource = """#: 00-8C-41-10-00-00-31-10-12-05-42-44-00-2E
+#, max-length:10
+msgctxt "0"
+msgid "Aurora"
+msgstr ""
+"""
+        pofile = self.poparse(posource)
+        print(pofile)
+        assert len(pofile.units) == 1
+        assert bytes(pofile).decode('utf-8') == posource
+        unit = pofile.units[0]
+        assert unit.typecomments == ["#, max-length:10\n"]
+        assert unit.hastypecomment("max-length:10") is True
+        unit.target = "Aurora"
+        unit.markfuzzy()
+        assert unit.typecomments == ["#, fuzzy, max-length:10\n"]
+        assert unit.hastypecomment("max-length:10") is True
+
     def test_unassociated_comments(self):
         """tests behaviour of unassociated comments."""
         oldsource = '# old lonesome comment\n\nmsgid "one"\nmsgstr "een"\n'
@@ -271,6 +289,33 @@ class TestPYPOFile(test_po.TestPOFile):
         print(bytes(oldfile))
         assert len(oldfile.units) == 1
 
+    def test_unicode_header(self):
+        """checks that unicode header is parsed and saved correctly"""
+        posource = r'''msgid ""
+msgstr ""
+"PO-Revision-Date: 2006-02-09 23:33+0200\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8-bit\n"
+"Zkouška: něco\n"
+'''.encode('utf-8')
+        pofile = self.poparse(posource)
+        assert pofile.parseheader() == {
+            'Content-Transfer-Encoding': '8-bit',
+            'Content-Type': 'text/plain; charset=UTF-8',
+            'MIME-Version': '1.0',
+            'PO-Revision-Date': '2006-02-09 23:33+0200',
+            'Zkouška': 'něco'
+        }
+        update = {'zkouška': 'else'}
+        pofile.updateheader(add=True, **update)
+        assert pofile.units[0].target == """PO-Revision-Date: 2006-02-09 23:33+0200
+MIME-Version: 1.0
+Content-Type: text/plain; charset=UTF-8
+Content-Transfer-Encoding: 8-bit
+Zkouška: else
+"""
+
     def test_prevmsgid_parse(self):
         """checks that prevmsgid (i.e. #|) is parsed and saved correctly"""
         posource = r'''msgid ""
@@ -323,3 +368,169 @@ msgstr[1] "toetse"
         assert pofile.units[4].prev_source == multistring([u"tast", u"tasts"])
 
         assert bytes(pofile).decode('utf-8') == posource
+
+    def test_wrap(self):
+        hello = ' '.join(['Hello'] * 100)
+        posource = 'msgid "{0}"\nmsgstr "{0}"\n'.format(hello).encode('utf-8')
+
+        # Instance with no line wraps
+        store = self.StoreClass(width=-1)
+        store.parse(posource)
+        assert bytes(store) == posource
+        store.units[0].target = hello
+        assert bytes(store) == posource
+
+        # Instance with long line wraps
+        store = self.StoreClass(width=1000)
+        store.parse(posource)
+        assert bytes(store) == posource
+        store.units[0].target = hello
+        assert bytes(store) == posource
+
+        # Instance with default wraps (77)
+        store = self.StoreClass()
+        store.parse(posource)
+        assert bytes(store) == posource
+        store.units[0].target = 'Hello ' * 100
+        # Should contain additional newlines now
+        assert bytes(store) != posource
+
+    def test_wrap_newlines(self):
+        hello = '\n '.join(['Hello'] * 100)
+        posource = 'msgid "{0}"\nmsgstr "{0}"\n'.format(hello.replace('\n', '\\n')).encode('utf-8')
+
+        # Instance with no line wraps
+        store = self.StoreClass(width=-1)
+        store.parse(posource)
+        assert bytes(store) == posource
+        store.units[0].target = hello
+        assert bytes(store) == posource
+
+        # Instance with default wraps (77)
+        store = self.StoreClass()
+        store.parse(posource)
+        assert bytes(store) == posource
+        store.units[0].target = 'Hello ' * 100
+        # Should contain additional newlines now
+        assert bytes(store) != posource
+
+    def test_unix_newlines(self):
+        """checks that unix newlines are properly parsed"""
+        posource = b'\nmsgid "test me"\nmsgstr ""\n'
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 1
+        assert pofile.units[0].source == 'test me'
+
+    def test_dos_newlines(self):
+        """checks that dos newlines are properly parsed"""
+        posource = b'\r\nmsgid "test me"\r\nmsgstr ""\r\n'
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 1
+        assert pofile.units[0].source == 'test me'
+
+    def test_mac_newlines(self):
+        """checks that mac newlines are properly parsed"""
+        posource = b'\rmsgid "test me"\rmsgstr ""\r'
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 1
+        assert pofile.units[0].source == 'test me'
+
+    def test_mixed_newlines(self):
+        """checks that mixed newlines are properly parsed"""
+        posource = b'''#Comment
+#: foo.c:124\r bar.c:124\r
+msgid "test me"
+msgstr ""
+'''
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 1
+        assert pofile.units[0].source == 'test me'
+        assert bytes(pofile) == posource
+
+    def test_mixed_newlines_header(self):
+        """checks that mixed newlines are properly parsed"""
+        posource = b'''# Polish message file for YaST2 (@memory@).\r
+# Copyright (C) 2005 SUSE Linux Products GmbH.\r
+msgid ""
+msgstr ""
+"Project-Id-Version: YaST (@memory@)\\n"
+
+#. Rich text title for FcoeClient in proposals
+#: src/clients/fcoe-client_proposal.rb:82
+msgid "FcoeClient"
+msgstr "FcoeClient"
+'''
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 2
+        assert pofile.units[0].source == ''
+        assert pofile.units[1].source == 'FcoeClient'
+        print(repr(bytes(pofile)))
+        assert bytes(pofile) == posource
+
+    def test_bom(self):
+        """checks that BOM is parsed"""
+        posource = '''msgid ""
+msgstr ""
+"Project-Id-Version: YaST (@memory@)\\n"
+
+msgid "FcoeClient"
+msgstr "FcoeClient"
+'''.encode('utf-8-sig')
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 2
+        assert pofile.units[0].source == ''
+        assert pofile.units[1].source == 'FcoeClient'
+        assert bytes(pofile) == posource[3:]
+
+    def test_long_msgidcomments(self):
+        posource = """#: networkstatus/connectionmanager.cpp:148
+msgid ""
+"_: Message shown when a network connection failed.  The placeholder contains "
+"the concrete description of the operation eg 'while performing this "
+"operation\\n"
+""
+"A network connection failed %1.  Do you want to place the application in "
+"offline mode?"
+msgstr ""
+"Připojení k síti se nezdařilo: %1. Chcete aplikaci přepnout do režimu "
+"offline?"
+"""
+        pofile = self.poparse(posource.encode('utf-8'))
+        assert len(pofile.units) == 1
+        assert bytes(pofile).decode('utf-8') == posource
+        posource_extra = """#: networkstatus/connectionmanager.cpp:148
+msgid ""
+""
+"_: Message shown when a network connection failed.  The placeholder contains "
+"the concrete description of the operation eg 'while performing this "
+"operation\\n"
+""
+"A network connection failed %1.  Do you want to place the application in "
+"offline mode?"
+msgstr ""
+"Připojení k síti se nezdařilo: %1. Chcete aplikaci přepnout do režimu "
+"offline?"
+"""
+        pofile = self.poparse(posource_extra.encode('utf-8'))
+        assert len(pofile.units) == 1
+        assert bytes(pofile).decode('utf-8') == posource
+
+    def test_incomplete(self):
+        """checks that empty file raises error"""
+        posource = b'''msgid ""
+msgstr ""
+"Project-Id-Version: YaST (@memory@)\\n"
+
+EXTRA
+'''
+        with raises(ValueError):
+            pofile = self.poparse(posource)
+
+    def test_invalid(self):
+        """checks that empty file raises error"""
+        posource = b'''README
+
+This is just a random text file.
+'''
+        with raises(ValueError):
+            pofile = self.poparse(posource)
