@@ -54,6 +54,63 @@ TS_NUMERUS = """<?xml version="1.0" encoding="utf-8"?>
         <source>func3</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&quot;Qt Linguist&apos;s&quot; format ain&apos;t that easy.
+The other line&apos;s translation may have quotes, too (&quot;&apos;&quot;,
+&apos;&quot;&apos;)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line 1
+
+Line 3</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+</TS>
+"""
+
+TS_CONTEXT_QT4 = """<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="cs">
+<defaultcodec>UTF-8</defaultcodec>
+<context>
+    <name></name>
+    <message>
+        <source>Hello, world!</source>
+        <translation>Ahoj svete!</translation>
+    </message>
+</context>
+<context>
+    <name>Second</name>
+    <message>
+        <source>Obsolete</source>
+        <translation type="obsolete">Thanks</translation>
+    </message>
+</context>
+</TS>
+"""
+
+TS_CONTEXT_QT5 = """<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="cs" sourcelanguage="en">
+<context>
+    <name></name>
+    <message>
+        <source>Hello, world!</source>
+        <translation>Ahoj svete!</translation>
+    </message>
+</context>
+<context>
+    <name>Second</name>
+    <message>
+        <source>Obsolete</source>
+        <translation type="vanished">Thanks</translation>
+    </message>
+    <message>
+        <source>Vanished</source>
+        <translation type="vanished">Thanks a lot</translation>
+    </message>
 </context>
 </TS>
 """
@@ -166,6 +223,20 @@ class TestTSfile(test_base.TestTranslationStore):
         )
         assert newtsstr == bytes(tsfile).decode('utf-8')
 
+    def test_obsolete(self):
+        tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT4)
+        assert tsfile.units[0].istranslatable()
+        assert not tsfile.units[0].isobsolete()
+        assert not tsfile.units[1].istranslatable()
+        assert tsfile.units[1].isobsolete()
+        tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT5)
+        assert tsfile.units[0].istranslatable()
+        assert not tsfile.units[0].isobsolete()
+        assert not tsfile.units[1].istranslatable()
+        assert tsfile.units[1].isobsolete()
+        assert not tsfile.units[2].istranslatable()
+        assert tsfile.units[2].isobsolete()
+
     def test_locations(self):
         """test that locations work well"""
         tsstr = '''<?xml version="1.0" encoding="utf-8"?>
@@ -183,13 +254,24 @@ class TestTSfile(test_base.TestTranslationStore):
         <source>Choose style and palette based on your desktop settings.</source>
         <translation>Stílus és paletta alapú kiválasztása az asztali beállításokban.</translation>
     </message>
+    <message>
+        <location />
+        <source>Choose style and palette based on your desktop settings.</source>
+        <translation>Stílus és paletta alapú kiválasztása az asztali beállításokban.</translation>
+    </message>
+    <message>
+        <source>Choose style and palette based on your desktop settings.</source>
+        <translation>Stílus és paletta alapú kiválasztása az asztali beállításokban.</translation>
+    </message>
 </context>
 </TS>
 '''
         tsfile = ts.tsfile.parsestring(tsstr)
-        assert len(tsfile.units) == 2
+        assert len(tsfile.units) == 4
         assert tsfile.units[0].getlocations() == ['../tools/qtconfig/mainwindow.cpp:+202']
         assert tsfile.units[1].getlocations() == ['+5']
+        assert tsfile.units[2].getlocations() == []
+        assert tsfile.units[3].getlocations() == []
 
     def test_merge_with_fuzzies(self):
         """test that merge with fuzzy works well"""
@@ -251,3 +333,34 @@ class TestTSfile(test_base.TestTranslationStore):
         """test that ts files are read and output properly"""
         tsfile = ts.tsfile.parsestring(TS_NUMERUS)
         assert bytes(tsfile).decode('utf-8') == TS_NUMERUS
+
+    def test_context(self):
+        tsfile = ts.tsfile.parsestring(TS_NUMERUS)
+        unit = tsfile.units[0]
+
+        contexts = [unit.getcontextname()]
+        commentnode = unit.xmlelement.find(unit.namespaced("comment"))
+        if commentnode is not None and commentnode.text is not None:
+            contexts.append(commentnode.text)
+        message_id = unit.xmlelement.get('id')
+        if message_id is not None:
+            contexts.append(message_id)
+        context = '\n'.join(filter(None, contexts))
+        assert unit.getcontext() == context
+        # setting the context does nothing atm - if the unit is inserted
+        unit.setcontext("FOO")
+        assert unit.getcontext() == context
+
+        # setting the context on a non-inserted unit works tho
+        newunit = unit.__class__("New unit")
+        assert newunit.getcontext() == ""
+        newunit.setcontext("")
+        assert newunit.getcontext() == ""
+        newunit.setcontext("Some context")
+        assert newunit.getcontext() == "Some context"
+
+    def test_roundtrip_context(self):
+        tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT4)
+        assert bytes(tsfile).decode('utf-8') == TS_CONTEXT_QT4
+        tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT5)
+        assert bytes(tsfile).decode('utf-8') == TS_CONTEXT_QT5
