@@ -36,7 +36,9 @@ import six
 from lxml import etree
 
 from translate.lang import data
+from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
+from translate.misc.xml_helpers import reindent
 from translate.storage import base, lisa
 from translate.storage.placeables import general
 from translate.storage.workflow import StateEnum as state
@@ -117,19 +119,36 @@ class tsunit(lisa.LISAunit):
 
     def getlanguageNodes(self):
         """We override this to get source and target nodes."""
-        return [n for n in [self._getsourcenode(), self._gettargetnode()] if n is not None]
+        return [n for n in [self._getsourcenode(), self._gettargetnode()]
+                if n is not None]
 
-    def getsource(self):
+    @lisa.LISAunit.source.getter
+    def source(self):
         # TODO: support <byte>. See bug 528.
         text = data.forceunicode(self._getsourcenode().text)
         if self.hasplural():
             return multistring([text])
-        else:
-            return text
-    source = property(getsource, lisa.LISAunit.setsource)
-    rich_source = property(base.TranslationUnit._get_rich_source, base.TranslationUnit._set_rich_source)
+        return text
 
-    def settarget(self, text):
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
+
+    @property
+    def target(self):
+        targetnode = self._gettargetnode()
+        if targetnode is None:
+            etree.SubElement(self.xmlelement, self.namespaced("translation"))
+            return None
+        if self.hasplural():
+            numerus_nodes = targetnode.findall(self.namespaced("numerusform"))
+            return multistring([data.forceunicode(node.text) or u"" for node in numerus_nodes])
+        else:
+            return data.forceunicode(targetnode.text) or u""
+
+    @target.setter
+    def target(self, target):
         # This is a fairly destructive implementation. Don't assume that this
         # is necessarily correct in all regards, but it does deal with a lot of
         # cases. It is hard to deal with plurals.
@@ -137,15 +156,15 @@ class tsunit(lisa.LISAunit):
         # Firstly deal with reinitialising to None or setting to identical
         # string.
         self._rich_target = None
-        if self.target == text:
+        if self.target == target:
             return
         strings = []
-        if isinstance(text, multistring):
-            strings = text.strings
-        elif isinstance(text, list):
-            strings = text
+        if isinstance(target, multistring):
+            strings = target.strings
+        elif isinstance(target, list):
+            strings = target
         else:
-            strings = [text]
+            strings = [target]
         targetnode = self._gettargetnode()
         type = targetnode.get("type")
         targetnode.clear()
@@ -156,24 +175,13 @@ class tsunit(lisa.LISAunit):
             for string in strings:
                 numerus = etree.SubElement(targetnode, self.namespaced("numerusform"))
                 numerus.text = data.forceunicode(string) or u""
-                # manual, nasty pretty printing. See bug 1420.
-                numerus.tail = u"\n        "
         else:
-            targetnode.text = data.forceunicode(text) or u""
-            targetnode.tail = u"\n    "
+            targetnode.text = data.forceunicode(target) or u""
 
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
     def gettarget(self):
-        targetnode = self._gettargetnode()
-        if targetnode is None:
-            etree.SubElement(self.xmlelement, self.namespaced("translation"))
-            return None
-        if self.hasplural():
-            numerus_nodes = targetnode.findall(self.namespaced("numerusform"))
-            return multistring([data.forceunicode(node.text) or u"" for node in numerus_nodes])
-        else:
-            return data.forceunicode(targetnode.text) or u""
-    target = property(gettarget, settarget)
-    rich_target = property(base.TranslationUnit._get_rich_target, base.TranslationUnit._set_rich_target)
+        return self.target
 
     def hasplural(self):
         return self.xmlelement.get("numerus") == "yes"
@@ -189,7 +197,9 @@ class tsunit(lisa.LISAunit):
         else:
             note = etree.SubElement(self.xmlelement, self.namespaced("translatorcomment"))
         if position == "append":
-            note.text = "\n".join(filter(None, [current_notes, text.strip()]))
+            note.text = "\n".join([item
+                                   for item in [current_notes, text.strip()]
+                                   if item])
         else:
             note.text = text.strip()
 
@@ -339,7 +349,7 @@ class tsunit(lisa.LISAunit):
             self.markfuzzy(False)
 
     def isobsolete(self):
-        return self._gettype() == "obsolete"
+        return self._gettype() == "obsolete" or self._gettype() == "vanished"
 
     def get_state_n(self):
         type = self._gettype()
@@ -350,6 +360,8 @@ class tsunit(lisa.LISAunit):
                 return self.S_FUZZY
             else:
                 return self.S_UNTRANSLATED
+        elif type == "vanished":
+            return self.S_OBSOLETE
         return self.statemap[type]
 
     def set_state_n(self, value):
@@ -433,7 +445,7 @@ class tsfile(lisa.LISAfile):
         name = etree.SubElement(context, self.namespaced("name"))
         name.text = contextname
         if comment:
-            comment_node = context.SubElement(context, "comment")
+            comment_node = etree.SubElement(context, "comment")
             comment_node.text = comment
         return context
 
@@ -455,7 +467,7 @@ class tsfile(lisa.LISAfile):
                 return contextnode
         return None
 
-    def addunit(self, unit, new=True, contextname=None, createifmissing=True):
+    def addunit(self, unit, new=True, contextname=None, comment=None, createifmissing=True):
         """Adds the given unit to the last used body node (current context).
 
         If the contextname is specified, switch to that context (creating it if
@@ -465,13 +477,13 @@ class tsfile(lisa.LISAfile):
             contextname = unit.getcontextname()
 
         if self._contextname != contextname:
-            if not self._switchcontext(contextname, createifmissing):
+            if not self._switchcontext(contextname, comment, createifmissing):
                 return None
         super(tsfile, self).addunit(unit, new)
 #        lisa.setXMLspace(unit.xmlelement, "preserve")
         return unit
 
-    def _switchcontext(self, contextname, createifmissing=False):
+    def _switchcontext(self, contextname, comment, createifmissing=False):
         """Switch the current context to the one named contextname, optionally
         creating it if it doesn't exist.
         """
@@ -480,7 +492,7 @@ class tsfile(lisa.LISAfile):
         if contextnode is None:
             if not createifmissing:
                 return False
-            contextnode = self._createcontext(contextname)
+            contextnode = self._createcontext(contextname, comment)
 
         self.body = contextnode
         if self.body is None:
@@ -497,6 +509,7 @@ class tsfile(lisa.LISAfile):
     def serialize(self, out):
         """Write the XML document to a file."""
         root = self.document.getroot()
+        reindent(root, indent="    ", skip=['TS'])
         doctype = self.document.docinfo.doctype
         # Iterate over empty tags without children and force empty text
         # This will prevent self-closing tags in pretty_print mode
