@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # This file is part of translate.
@@ -80,7 +79,7 @@ class TerminologyExtractor(object):
         if stopfile is None:
             try:
                 stopfile = file_discovery.get_abs_data_filename('stoplist-%s' % self.sourcelanguage)
-            except:
+            except Exception:
                 pass
         self.stopfile = stopfile
         self.parse_stopword_file()
