@@ -1,15 +1,13 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 import warnings
 
 from pytest import mark
 
-from translate.tools import pretranslate
 from translate.convert import test_convert
 from translate.misc import wStringIO
-from translate.storage import po
-from translate.storage import xliff
+from translate.storage import po, xliff
+from translate.tools import pretranslate
 
 
 class TestPretranslate:
@@ -57,11 +55,11 @@ class TestPretranslate:
     def singleunit(self, pofile):
         """checks that the pofile contains a single non-header unit, and
         returns it"""
-        if len(pofile.units) == 2 and  pofile.units[0].isheader():
-            print pofile.units[1]
+        if len(pofile.units) == 2 and pofile.units[0].isheader():
+            print(pofile.units[1])
             return pofile.units[1]
         else:
-            print pofile.units[0]
+            print(pofile.units[0])
             return pofile.units[0]
 
     def test_pretranslatepo_blank(self):
@@ -122,8 +120,8 @@ msgstr[1] "%d handleidings."
         template_source = '''#: simple.label\n#: simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
         poexpected = '''#: simple.label\n#: simple.accesskey\n#, fuzzy\nmsgid "Its &hard coding a newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
         newpo = self.pretranslatepo(input_source, template_source)
-        print newpo
-        assert str(newpo) == poexpected
+        print(bytes(newpo))
+        assert bytes(newpo).decode('utf-8') == poexpected
 
     def test_merging_location_change(self):
         """tests that if the location changes but the msgid stays the same that
@@ -132,8 +130,8 @@ msgstr[1] "%d handleidings."
         template_source = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         poexpected = '''#: new_simple.label%snew_simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         newpo = self.pretranslatepo(input_source, template_source)
-        print newpo
-        assert str(newpo) == poexpected
+        print(bytes(newpo))
+        assert bytes(newpo).decode('utf-8') == poexpected
 
     def test_merging_location_and_whitespace_change(self):
         """test that even if the location changes that if the msgid only has
@@ -142,8 +140,8 @@ msgstr[1] "%d handleidings."
         template_source = '''#: doublespace.label%sdoublespace.accesskey\nmsgid "&We  have  spaces"\nmsgstr "&One  het  spasies"\n''' % po.lsep
         poexpected = '''#: singlespace.label%ssinglespace.accesskey\n#, fuzzy\nmsgid "&We have spaces"\nmsgstr "&One  het  spasies"\n''' % po.lsep
         newpo = self.pretranslatepo(input_source, template_source)
-        print newpo
-        assert str(newpo) == poexpected
+        print(bytes(newpo))
+        assert bytes(newpo).decode('utf-8') == poexpected
 
     @mark.xfail(reason="Not Implemented")
     def test_merging_accelerator_changes(self):
@@ -153,8 +151,8 @@ msgstr[1] "%d handleidings."
         template_source = '''#: someline.c\nmsgid "&About"\nmsgstr "&Info"\n'''
         poexpected = '''#: someline.c\nmsgid "A&bout"\nmsgstr "&Info"\n'''
         newpo = self.pretranslatepo(input_source, template_source)
-        print newpo
-        assert str(newpo) == poexpected
+        print(bytes(newpo))
+        assert bytes(newpo).decode('utf-8') == poexpected
 
     @mark.xfail(reason="Not Implemented")
     def test_lines_cut_differently(self):
@@ -209,10 +207,10 @@ msgstr "Sekuriteit"
         poexpected = template_source
         newpo = self.pretranslatepo(input_source, template_source)
         newpounit = self.singleunit(newpo)
-        print "expected"
-        print poexpected
-        print "got:"
-        print str(newpounit)
+        print("expected")
+        print(poexpected)
+        print("got:")
+        print(str(newpounit))
         assert str(newpounit) == poexpected
 
     def test_merging_msgidcomments(self):
@@ -238,7 +236,7 @@ msgstr "36em"
         input_source = '''msgid "One"\nmsgid_plural "Two"\nmsgstr[0] ""\nmsgstr[1] ""\n'''
         template_source = '''msgid "One"\nmsgid_plural "Two"\nmsgstr[0] "Een"\nmsgstr[1] "Twee"\nmsgstr[2] "Drie"\n'''
         newpo = self.pretranslatepo(input_source, template_source)
-        print newpo
+        print(newpo)
         newpounit = self.singleunit(newpo)
         assert str(newpounit) == template_source
 
@@ -249,8 +247,8 @@ msgstr "36em"
         template_source = '''#~ msgid "&About"\n#~ msgstr "&Omtrent"\n'''
         expected = '''#: resurect.c\nmsgid "&About"\nmsgstr "&Omtrent"\n'''
         newpo = self.pretranslatepo(input_source, template_source)
-        print newpo
-        assert str(newpo) == expected
+        print(bytes(newpo))
+        assert bytes(newpo).decode('utf-8') == expected
 
     def test_merging_comments(self):
         """Test that we can merge comments correctly"""
@@ -258,7 +256,7 @@ msgstr "36em"
         template_source = '''#. Don't do it!\n#: file.py:2\nmsgid "One"\nmsgstr "Een"\n'''
         poexpected = '''#. Don't do it!\n#: file.py:1\nmsgid "One"\nmsgstr "Een"\n'''
         newpo = self.pretranslatepo(input_source, template_source)
-        print newpo
+        print(newpo)
         newpounit = self.singleunit(newpo)
         assert str(newpounit) == poexpected
 
@@ -269,7 +267,7 @@ msgstr "36em"
         poexpected = '''#: file.c:1\n#, c-format\nmsgid "%d pipes"\nmsgstr "%d pype"\n'''
         newpo = self.pretranslatepo(input_source, template_source)
         newpounit = self.singleunit(newpo)
-        print newpounit
+        print(newpounit)
         assert str(newpounit) == poexpected
 
         input_source = '''#: file.c:1\n#, c-format\nmsgid "%d computers"\nmsgstr ""\n'''
@@ -282,22 +280,22 @@ msgstr "36em"
 
     def test_xliff_states(self):
         """Test correct maintenance of XLIFF states."""
-        xlf_template = self.xliff_skeleton \
-          % '''<trans-unit id="1" xml:space="preserve">
+        xlf_template = self.xliff_skeleton % (
+            '''<trans-unit id="1" xml:space="preserve">
                    <source> File  1 </source>
-               </trans-unit>'''
-        xlf_old = self.xliff_skeleton \
-          % '''<trans-unit id="1" xml:space="preserve" approved="yes">
+               </trans-unit>''')
+        xlf_old = self.xliff_skeleton % (
+            '''<trans-unit id="1" xml:space="preserve" approved="yes">
                    <source> File  1 </source>
                    <target> Lêer 1 </target>
-               </trans-unit>'''
+               </trans-unit>''')
 
         template = xliff.xlifffile.parsestring(xlf_template)
         old = xliff.xlifffile.parsestring(xlf_old)
         new = self.pretranslatexliff(template, old)
-        print str(old)
-        print '---'
-        print str(new)
+        print(bytes(old))
+        print('---')
+        print(bytes(new))
         assert new.units[0].isapproved()
         # Layout might have changed, so we won't compare the serialised
         # versions
@@ -307,9 +305,9 @@ class TestPretranslateCommand(test_convert.TestConvertCommand, TestPretranslate)
     """Tests running actual pretranslate commands on files"""
     convertmodule = pretranslate
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--tm")
         options = self.help_check(options, "-s MIN_SIMILARITY, --similarity=MIN_SIMILARITY")
